core/exceptions library

Custom exceptions for playerctl operations

Exceptions / Errors

CommandExecutionException
Exception thrown when a command execution fails
InvalidVolumeException
Exception thrown when volume value is invalid
MetadataParsingException
Exception thrown when metadata parsing fails
NoPlayerException
Exception thrown when no media player is currently running
PlayerctlException
Base exception for all playerctl-related errors
PlayerctlNotInstalledException
Exception thrown when playerctl is not installed on the system