LogLevel enum

Log levels for the playerctl package

Inheritance
Available extensions

Values

none → const LogLevel

No logging

const LogLevel(0)
error → const LogLevel

Only errors

const LogLevel(1)
warning → const LogLevel

Warnings and errors

const LogLevel(2)
info → const LogLevel

Info, warnings, and errors

const LogLevel(3)
debug → const LogLevel

All logs including debug

const LogLevel(4)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator <(LogLevel other) bool
operator <=(LogLevel other) bool
operator ==(Object other) bool
The equality operator.
inherited
operator >(LogLevel other) bool
operator >=(LogLevel other) bool

Constants

values → const List<LogLevel>
A constant List of the values in this enum, in order of their declaration.