IPlaybackController class abstract

Interface for playback control operations

Implementers

Constructors

IPlaybackController()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

next([String? player]) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause([String? player]) Future<bool>
play([String? player]) Future<bool>
playPause([String? player]) Future<bool>
previous([String? player]) Future<bool>
stop([String? player]) Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited