AlbumArtServer class

HTTP server for serving album art files locally This allows album art to be accessed from other devices on the network

Constructors

AlbumArtServer()

Properties

hashCode int
The hash code for this object.
no setterinherited
isRunning bool
Check if server is running
no setter
port int?
Get the server port
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerFile(String filePath) String?
Register a file to be served and get the URL
start({int port = defaultPort}) Future<String?>
Start the HTTP server on 0.0.0.0
stop() Future<void>
Stop the server
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultPort → const int