MetadataProvider class

Metadata provider for fetching and streaming media metadata Follows Single Responsibility Principle

Implemented types

Constructors

MetadataProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Cleanup resources
getCurrentMetadata([String? player]) Future<Map<String, String>>
override
listenToMetadata([String? player]) Stream<Map<String, String>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stopListening() Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited