PlaybackController class

Playback controller for media playback operations Follows Single Responsibility Principle

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cycleLoop([String? player]) Future<bool>
Cycle through loop modes: None → Track → Playlist → None
getLoop([String? player]) Future<String?>
Get loop status
getPosition([String? player]) Future<int?>
Get current position in microseconds
getShuffle([String? player]) Future<String?>
Get shuffle status
next([String? player]) Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause([String? player]) Future<bool>
override
play([String? player]) Future<bool>
override
playPause([String? player]) Future<bool>
override
previous([String? player]) Future<bool>
override
seek(int offsetMicroseconds, [String? player]) Future<bool>
Seek forward by offset in microseconds (use negative value to seek backward)
seekBackward(int seconds, [String? player]) Future<bool>
Seek backward by seconds
seekForward(int seconds, [String? player]) Future<bool>
Seek forward by seconds
seekTo(int positionMicroseconds, [String? player]) Future<bool>
Seek to absolute position in microseconds
setLoop(String status, [String? player]) Future<bool>
Set loop status (None/Track/Playlist)
setShuffle(String status, [String? player]) Future<bool>
Set shuffle status (On/Off)
stop([String? player]) Future<bool>
override
toggleShuffle([String? player]) Future<bool>
Toggle shuffle
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited