PlayerDetector class

Player detector for finding and listing media players Follows Single Responsibility Principle

Implemented types

Constructors

PlayerDetector()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getActivePlayerName() Future<String?>
Get the currently active player name
getAvailablePlayers() Future<List<String>>
override
hasActivePlayer() Future<bool>
override
isPlayerAvailable(String playerName) Future<bool>
Check if a specific player is available
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited