PlayerctlSystemChecker class
System checker for playerctl installation and version Follows Single Responsibility Principle
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
ensurePlayerctlInstalled(
) → Future< void> - Validates that playerctl is installed, throws exception if not
-
getPlayerctlVersion(
) → Future< String?> -
override
-
isPlayerctlInstalled(
) → Future< bool> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited