VolumeController class

Volume controller for managing player volume Follows Single Responsibility Principle

Implemented types

Constructors

VolumeController(PlayerctlCommandExecutor _executor)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decreaseVolume(int percentage, [String? player]) Future<bool>
Decrease volume by percentage
getVolume([String? player]) Future<int?>
override
increaseVolume(int percentage, [String? player]) Future<bool>
Increase volume by percentage
mute([String? player]) Future<bool>
Mute the player (set volume to 0)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setVolume(int volume, [String? player]) Future<bool>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited