PlayerctlLogger class
Logger utility for playerctl package
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
debug(
String message, [String? tag]) → void - Log a debug message (verbose/trace level)
-
disableAll(
) → void - Disable all logs
-
enableAll(
) → void - Enable all logs (debug level)
-
error(
String message, [String? tag, Object? error]) → void - Log an error message
-
info(
String message, [String? tag]) → void - Log an info message
-
metadata(
String message, [String? tag]) → void - Log metadata updates (debug level)
-
network(
String message, [String? tag]) → void - Log network/server events (debug level)
-
player(
String message, [String? tag]) → void - Log player events (info level)
-
success(
String message, [String? tag]) → void - Log a success message (info level)
-
sync(
String message, [String? tag]) → void - Log sync/timer events (debug level)
-
volume(
String message, [String? tag]) → void - Log volume events (debug level)
-
warning(
String message, [String? tag]) → void - Log a warning message