MediaInfo class

Represents the current media playback information

Constructors

MediaInfo({String title = 'Unknown', String artist = 'Unknown', String album = 'Unknown', String status = 'Stopped', String playerName = 'Unknown', int? position, int? length, String? artUrl})
const
MediaInfo.empty()
Creates an empty MediaInfo (no active player)
factory
MediaInfo.fromJson(Map<String, dynamic> json)
Create MediaInfo from JSON
factory

Properties

album String
final
artist String
final
artUrl String?
final
hashCode int
The hash code for this object.
no setterinherited
length int?
final
playerName String
final
position int?
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
title String
final

Methods

copyWith({String? title, String? artist, String? album, String? status, String? playerName, int? position, int? length, String? artUrl}) MediaInfo
Copy with method for updating specific fields
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert MediaInfo to JSON
toString() String
A string representation of this object.

Operators

operator ==(Object other) bool
The equality operator.
inherited