AlbumArtServer class
HTTP server for serving album art files locally This allows album art to be accessed from other devices on the network
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerFile(
String filePath) → String? - Register a file to be served and get the URL
-
start(
{int port = defaultPort}) → Future< String?> - Start the HTTP server on 0.0.0.0
-
stop(
) → Future< void> - Stop the server
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultPort → const int