PlayerctlCommandExecutor class
Command executor for running playerctl commands Follows Single Responsibility Principle - only handles command execution
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
executeCommand(
String command, [String? player]) → Future< bool> -
override
-
executeCommandWithArgs(
List< String> args) → Future<bool> - Execute a command with custom arguments
-
executeCommandWithOutput(
String command, [String? player]) → Future< String?> - Execute a command and get the output
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited